@@ -12,6 +12,7 @@ JSON-RPC functionality.
 
 Usage:
     from coinbridge import Bridge
+    
     bridge = Bridge()
     bridge.payment(from_account, to_account, amount)
 
@@ -37,13 +38,12 @@ from functools import wraps
 import pyjsonrpc
 import db
 
-__title__      = "Coinbridge"
-__version__    = "0.1.2"
+__title__      = "coinbridge"
+__version__    = "0.1.3"
 __author__     = "Jack Peterson"
-__copyright__  = "Copyright 2014, Dyffy Inc."
 __license__    = "MIT"
 __maintainer__ = "Jack Peterson"
-__email__      = "jack@dyffy.com"
+__email__      = "jack@tinybike.net"
 
 _IS_PYTHON_3 = (platform.version() >= '3')
 identity = lambda x : x
@@ -341,6 +341,7 @@ class Bridge(object):
 
         Returns:
           str: Base58Check address for this account
+
         """
         address = self.rpc.call("getaccountaddress", user_id)
         self.logger.debug("Your", self.coin, "address is", address)
@@ -357,6 +358,7 @@ class Bridge(object):
 
         Returns:
           str or Decimal: this account's total coin balance
+
         """
         balance = unicode(self.rpc.call("getbalance", user_id))
         self.logger.debug("\"" + user_id + "\"", self.coin, "balance:", balance)
@@ -389,6 +391,7 @@ class Bridge(object):
 
         Returns:
           list [dict]: transactions associated with this user's account
+
         """
         txlist = self.rpc.call("listtransactions", user_id, count, start_at)
         self.logger.debug("Got transaction list for " + str(user_id))
@@ -410,6 +413,7 @@ class Bridge(object):
 
         Returns:
           bool: True if the coins are moved successfully, False otherwise
+
         """
         amount = Decimal(amount).quantize(self.quantum, rounding=ROUND_HALF_EVEN)
         return self.rpc.call("move",
@@ -430,6 +434,7 @@ class Bridge(object):
 
         Returns:
           str: transaction ID
+
         """
         amount = Decimal(amount).quantize(self.quantum, rounding=ROUND_HALF_EVEN)
         txhash = self.rpc.call("sendfrom",
@@ -463,6 +468,7 @@ class Bridge(object):
         Args:
           timeout (int): how many seconds the wallet will remain unlocked.
                          (default=30)
+
         """
         return self.walletpassphrase(int(timeout))
 
@@ -472,6 +478,7 @@ class Bridge(object):
 
         Locking a wallet prohibits certain restricted commands, such as
         spending coins, signing messages, etc.
+
         """
         self.rpc.call("walletlock")
 
@@ -488,6 +495,7 @@ class Bridge(object):
 
         Returns:
           str: ECDSA signature over the message
+
         """
         signature = self.rpc.call("signmessage", address, message)
         self.logger.debug("Signature: %s" % signature)
@@ -505,6 +513,7 @@ class Bridge(object):
 
         Returns:
           bool: True if the address signed the message, False otherwise
+
         """
         verified = self.rpc.call("verifymessage", address, signature, message)
         self.logger.debug("Signature verified: %s" % str(verified))
@@ -517,6 +526,7 @@ class Bridge(object):
 
         Args:
           command (str): command to be sent to the coin daemon
+
         """
         return self.rpc.call(str(command), *args)
 
